@@ -31,7 +31,7 @@ def openX11(dsets=[]):
 
 def _dset_raw_info(dset):
     ''' returns raw output from running ``3dinfo`` '''
-    return subprocess.check_output(['3dinfo','-verb',dset],stderr=subprocess.STDOUT)
+    return subprocess.check_output(['3dinfo','-verb',str(dset)],stderr=subprocess.STDOUT)
 
 class DsetInfo:
     ''' contains organized output from ``3dinfo`` 
@@ -47,6 +47,7 @@ class DsetInfo:
         self.spatial_to = []
         self.slice_timing = None
         self.TR = None
+        self.orient = None
     
     def subbrick_labeled(self,label):
         for i in xrange(len(self.subbricks)):
@@ -70,6 +71,9 @@ def dset_info(dset):
     info.reps = len(info.subbricks)
     # Dimensions:
     
+    orient = re.search('\[-orient ([A-Z]+)\]',raw_info)
+    if orient:
+        info.orient = orient.group(1)
     for axis in ['RL','AP','IS']:
         m = re.search(r'%s-to-%s extent:\s+([0-9-.]+) \[%s\] -to-\s+([0-9-.]+) \[%s\] -step-\s+([0-9-.]+) mm \[([0-9]+) voxels\]' % (axis[0],axis[1],axis[0],axis[1]),raw_info)
         if m:
@@ -205,7 +209,7 @@ def voxel_count(dset,subbrick=0,p=None,positive_only=False,mask=None,ROI=None):
     devnull = open(os.devnull,"w")
     if mask:
         cmd = ['3dROIstats','-1Dformat','-nomeanout','-nobriklab', '-nzvoxels']
-        cmd += ['-mask',mask,dset]
+        cmd += ['-mask',str(mask),str(dset)]
         out = subprocess.check_output(cmd,stderr=devnull).split('\n')
         if len(out)<4:
             return 0
@@ -228,7 +232,7 @@ def voxel_count(dset,subbrick=0,p=None,positive_only=False,mask=None,ROI=None):
                 else:
                     count += roi_count
     else:
-        cmd = ['3dBrickStat', '-slow', '-count', '-non-zero', dset]
+        cmd = ['3dBrickStat', '-slow', '-count', '-non-zero', str(dset)]
         count = int(subprocess.check_output(cmd,stderr=devnull).strip())
     if count_dict:
         return count_dict
@@ -248,7 +252,7 @@ def afni_copy(filename):
     ''' creates a ``+orig`` copy of the given dataset and returns the filename as a string '''
     afni_filename = "%s+orig" % prefix(filename)
     if not os.path.exists(afni_filename + ".HEAD"):
-        subprocess.call(['3dcalc','-a',filename,'-expr','a','-prefix',prefix(filename)])
+        subprocess.call(['3dcalc','-a',str(filename),'-expr','a','-prefix',prefix(filename)])
     return afni_filename
 
 def nifti_copy(filename,copy_prefix=None):
@@ -259,7 +263,7 @@ def nifti_copy(filename,copy_prefix=None):
     if prefix:
         nifti_filename = prefix(copy_prefix) + ".nii.gz"
     if not os.path.exists(nifti_filename):
-        subprocess.call(['3dAFNItoNIFTI',filename,'-prefix',nifti_filename])
+        subprocess.call(['3dAFNItoNIFTI',str(filename),'-prefix',nifti_filename])
     return nifti_filename
 
 def is_nifti(filename):
@@ -275,6 +279,12 @@ def is_nifti(filename):
         else:
             return False
 
+def is_dset(filename):
+    '''just checks if the filename has the format of an fMRI dataset'''
+    afni_dset = '^.*\+(orig|acpc|tlrc)\.?(HEAD|BRIK)?(.gz|.bz)?$'
+    nifti_dset = '^.*\.nii(.gz|.bz)?$'
+    return (re.match(afni_dset,filename) or re.match(nifti_dset,filename))!=None
+
 class temp_afni_copy:
     ''' used within a ``with`` block, will create a temporary ``+orig`` copy of dataset
     
@@ -486,6 +496,7 @@ def tshift(dset,suffix='_tshft',initial_ignore=3):
     neural.run(['3dTshift','-prefix',neural.suffix(dset,suffix),'-ignore',initial_ignore,dset],products=neural.suffix(dset,suffix))
 
 def volreg(dset,suffix='_volreg',base_subbrick=3,tshift=True):
+    ''' simple interface to 3dvolreg (recommend looking at align_epi_anat instead of using this) '''
     cmd = ['3dvolreg','-prefix',neural.suffix(dset,suffix),'-base',base_subbrick]
     if tshift:
         cmd += ['-tshift',base_subbrick]
@@ -634,13 +645,19 @@ def qwarp_apply(dset_from,dset_warp,affine=None,warp_suffix='_warp',master='WARP
     
     Output dataset with have the ``warp_suffix`` suffix added to its name
     '''
-    warp = [dset_warp]
-    if affine:
-        warp.append(affine)
     out_dset = os.path.split(suffix(dset_from,warp_suffix))[1]
+    dset_from_info = dset_info(dset_from)
+    dset_warp_info = dset_info(dset_warp)
+    if(dset_from_info.orient!=dset_warp_info.orient):
+        # If the datasets are different orientations, the transform won't be applied correctly
+        nl.run(['3dresample','-orient',dset_warp_info.orient,'-prefix',suffix(dset_from,'_reorient'),'-inset',dset_from])
+        dset_from = suffix(dset_from,'_reorient')
     cmd = [
         '3dNwarpApply',
-        '-nwarp', ' '.join(warp),
+        '-nwarp', dset_warp]
+    if affine:
+        cmd += ['-affter', affine]
+    cmd += [
         '-source', dset_from,
         '-master',master,
         '-prefix', out_dset
@@ -665,7 +682,7 @@ def qwarp_invert(warp_param_dset,output_dset,affine_1Dfile=None):
     neural.run(cmd,products=output_dset)
 
 def skull_strip(dset,out_suffix='_ns'):
-    ''' runs 3dSkullStrip '''
+    ''' runs 3dSkullStrip (I would recommend looking at fsl.bet instead)'''
     neural.run([
         '3dSkullStrip',
         '-input', dset,
@@ -737,7 +754,7 @@ def create_censor_file(input_dset,out_prefix=None,fraction=0.1,clip_to=0.1,max_e
     '''
     polort = auto_polort(input_dset)
     info = dset_info(input_dset)
-    outcount = [float(x.split()[0]) for x in subprocess.check_output(['3dToutcount','-fraction','-automask','-polort',polort,input_dset]).split('\n')]
+    outcount = [float(x.split()[0]) for x in subprocess.check_output(['3dToutcount','-fraction','-automask','-polort',str(polort),str(input_dset)]).split('\n')]
     binary_outcount = [x<fraction for x in outcount]
     perc_outliers = sum(binary_outcount)/float(info.reps)
     if max_exclude and perc_outliers > max_exclude:
@@ -750,4 +767,4 @@ def create_censor_file(input_dset,out_prefix=None,fraction=0.1,clip_to=0.1,max_e
     if not out_prefix:
         out_prefix = prefix(input_dset) + '.1D'
     with open(out_prefix,'w') as f:
-        f.write('\n'.join([str(int(x)) for x in binary_outcount]))
\ No newline at end of file
+        f.write('\n'.join([str(int(x)) for x in binary_outcount]))
